@@ -4,6 +4,7 @@ import random
 import string
 import sys
 
+from iker.common.utils.dtutils import dt_utc_max, dt_utc_min
 from iker.common.utils.funcutils import memorized, singleton
 
 __all__ = [
@@ -80,28 +81,28 @@ class Randomizer(object):
 
     def random_datetime(
         self,
-        begin: datetime.datetime = datetime.datetime.min,
-        end: datetime.datetime = datetime.datetime.max,
+        begin: datetime.datetime = dt_utc_min(),
+        end: datetime.datetime = dt_utc_max(),
     ) -> datetime.datetime:
         return begin + datetime.timedelta(seconds=self.next_float(0.0, (end - begin).total_seconds()))
 
     def random_date(
         self,
-        begin: datetime.date = datetime.date.min,
-        end: datetime.date = datetime.date.max,
+        begin: datetime.date = dt_utc_min().date(),
+        end: datetime.date = dt_utc_max().date(),
     ) -> datetime.date:
-        dt = self.random_datetime(datetime.datetime.combine(begin, datetime.time.min),
-                                  datetime.datetime.combine(end, datetime.time.min))
+        dt = self.random_datetime(datetime.datetime.combine(begin, dt_utc_min().timetz()),
+                                  datetime.datetime.combine(end, dt_utc_min().timetz()))
         return dt.date()
 
     def random_time(
         self,
-        begin: datetime.time = datetime.time.min,
-        end: datetime.time = datetime.time.max,
+        begin: datetime.time = dt_utc_min().timetz(),
+        end: datetime.time = dt_utc_max().timetz(),
     ) -> datetime.time:
-        dt = self.random_datetime(datetime.datetime.combine(datetime.date.min, begin),
-                                  datetime.datetime.combine(datetime.date.min, end))
-        return dt.time()
+        dt = self.random_datetime(datetime.datetime.combine(dt_utc_min().date(), begin),
+                                  datetime.datetime.combine(dt_utc_min().date(), end))
+        return dt.timetz()
 
     def random_json_object(
         self,
